@@ -22,6 +22,7 @@
                     "RgetShortArrayCont", "RgetStringArrayCont", "RidenticalRef", "RgetSimpleClassNames",
                     "RisAssignableFrom", "RpollException", "RsetField", "RthrowException",
                     "javaObjectCache", "initRJavaTools", "newRJavaLookupTable", "useDynamicSymbols",
+                    "RgetJVMstate",
                      # .External
                     "RcreateObject", "RgetStringValue", "RinitJVM", "RtoString", "RcallMethod",
                      # .C
@@ -45,10 +46,6 @@
   for (x in .delayed.variables) assign(x, NULL, .env)
   assign(".jniInitialized", FALSE, .env)
 
-  # default JVM initialization parameters
-  if (is.null(getOption("java.parameters")))
-    options("java.parameters"="-Xmx512m")
-  
   ## S4 classes update - all classes are created earlier in classes.R, but jobjRef's prototype is only valid after the dylib is loaded
   setClass("jobjRef", representation(jobj="externalptr", jclass="character"), prototype=list(jobj=.jzeroRef, jclass="java/lang/Object"), where=.env)  
 }
